@@ -1,4 +1,5 @@
-logbin.control <- function (bound.tol = 1e-06, epsilon = 1e-08, maxit = 10000, trace = 0) 
+logbin.control <- function (bound.tol = 1e-06, epsilon = 1e-08, maxit = 10000, trace = 0,
+                            coeftrace = FALSE) 
 {
     if (!is.numeric(bound.tol) || bound.tol <= 0)
         stop("value of 'bound.tol' must be > 0")
@@ -8,5 +9,6 @@ logbin.control <- function (bound.tol = 1e-06, epsilon = 1e-08, maxit = 10000, t
       warning("'epsilon' should be smaller than 'bound.tol'", call. = FALSE)
     if (!is.numeric(maxit) || maxit <= 0) 
         stop("maximum number of iterations must be > 0")
-    list(bound.tol = bound.tol, epsilon = epsilon, maxit = maxit, trace = trace)
+    list(bound.tol = bound.tol, epsilon = epsilon, maxit = maxit, trace = trace,
+         coeftrace = coeftrace)
 }
\ No newline at end of file
